# Django Admin Hotkeys

Add hotkeys to the Django admin interface to improve your workflow.

## Usage

1. `pip install django-admin-hotkeys`
2. Add `django_admin_hotkeys` to your `INSTALLED_APPS` in `settings.py`:
3. PROFIT!

## Hotkeys

- `/`: Focus the search box
- `n`: Navigate to "Add" page to create a new item
